*************************************************************************
*************************************************************************
*******								  *******
*******   THIS FILE LOADS IN DATA SETS MADE BY BUILD DEMAND.DO 	  *******
*******   AND CREATES CHOICE SETS AND RUNS DEMAND ESTIMATION FOR  *******
*******   THE ENTRY PAPER ON COMPETITION WITH PRICES AND 	  *******
*******   ADVERTISING					       	  *******
*******								  *******
*************************************************************************
*************************************************************************


	clear all
	set mem 32g
	set more off
	cap log close
	


	*** SET GLOBAL DIRECTORIES
	***********************************
	
	global root "/data/hastings2/CompletedPapers/HHS_ECMA_2017/_final/"
        global infile "${root}input/"
	global tempfile "${root}temp/"
	global outfile "${root}output/"
	global tables  "${root}output/tablesFigures/"
	global dir_log "${root}output/log/"		

	global date "20170206"

cap log close
log using "${dir_log}Step1_EstimateDemand_final_${date}.txt", replace

***************************************************************************
*** STEP 1: LOAD IN INCEPTION_MKT_TEMP AND ADD ON LOCATION INFORMATION  ***
***************************************************************************
	*** STEP 1.A: ZIPCODE AND ESTADO DATA MERGED ONTO INCEPTION MARKET DATA ***   		
		use "${infile}codigopostal_cities.dta", clear
     	  	  keep  afore_cp cod_post nss c_muni c_estado urbindex
     	  	  tab c_estado, m     
     	  	  tab c_muni, m       
     	  	  drop if c_muni=="" 
     	  	  tab c_estado, m
     	  	  egen muni=concat(c_estado c_muni)
     	  	  bysort muni:gen total_muni=_N
     	  	  bysort c_estado: gen total_state=_N
     	  	  keep nss c_estado muni total_muni total_state cod_post
     	  	  sort nss
   		save "${tempfile}tempzip", replace

		use "${infile}BaseAccountHistoryFile_${date}.dta", clear

		merge nss using "${tempfile}tempzip", sort nokeep
		 tab _merge 
		 drop if _merge==1 
		 drop _merge
  		 replace sar92sum = 0 if sar92sum==.		 
		save "${tempfile}tempbasezip", replace



***********************************************************************************************
*** STEP 2: CREATE DEMOGRAPHIC VARIABLES THAT WE NEED FOR DEMAND ESTIMATION, INCLUDING THE  ***
***   	DEMOGRAPHIC CELL GROUPS BY AGE, WAGE AND GENDER						  ***
***********************************************************************************************

	*** STEP 2.1: DEFINE AGE AND CLEAN (AGE >=14 & AGE<=65, CREATE AGE CATEGORIES FOR REGRESSIONS ***
	    use "${tempfile}tempbasezip", clear

            gen birthyear= year(fechanacimiento)
            gen birthmonth =  month(fechanacimiento)
            gen birthyear2 = birthyear+1 if birthmonth>6
            replace birthyear2 = birthyear if birthmonth<=6
		tab birthyear, m	
		gen age = (1997-birthyear2)		
		  tab age, m		
		  count if age<14 | age>=65	
		  drop if age<14 | age>=65  
		  drop birthyear birthyear2 birthmonth				
          
	    ** Define Years to Retirement, set 10 or more years as 10 since we'll look at a 10 year horizon **
            gen yrs_to_ret = 65 - age
            replace yrs_to_ret = 10 if yrs_to_ret>10	

            ** 4 Cells for age **
            gen byte xage4=.    	 	
    	    replace xage4 = 1 if age<=23
    	    replace xage4 = 2 if age>23 & age<30
    	    replace xage4 = 3 if age>=30 & age<40
            replace xage4 = 4 if age>=40 & age!=.
    	    tab xage4, m
    	    tab xage4, sum(age)
 		
	*** STEP 2.2: DEFINE A DAILY WAGE FOR A MEASURE OF INCOME/SKILL LEVEL ***
		*1. destring last wage in bdnsar
		 destring ultimoperiodopago, replace
		 tab ultimoperiodo, m  
		 sum expsdi_* if ultimoperiodo==.  
		 
		 destring salariodiariointegrado, replace			
		 replace salariodiariointegrado=. if salariodiariointegrado==0
		 rename ultimoperiodo yyyymm
		 sort yyyymm
		 merge yyyymm using "${infile}ipc_mex.dta"
		 tab _merge
		 tab yyyymm if _merge==1, m  
		 tab yyyymm if _merge==2  
		 drop if _merge==2 & yyyymm!=199706 & yyyymm!=200606 

		*2. now deflate the bdnsar sdi to Dec 1997 pesos (SDI from recaudacion files has already been deflated) 
		 sum ipc if yyyymm==199712
		 local base=r(mean)
		 gen sdi_bdnsar=salariodiariointegrado*(`base'/ipc)  
		 drop salariodiario
	         drop if _merge==2
		 drop _merge
		   
		 gen float wage=expsdi_1997 if expsdi_1997!=0				
		   replace wage=sdi_bdnsar if wage==. & sdi_!=. & yyyymm<199800
		   forvalues y=1998(1)2006 {
		      replace wage=expsdi_`y' if wage==. & expsdi_`y'!=. & expsdi_`y'!=0
		      replace wage=sdi_bdnsar if wage==. & sdi_!=. & yyyymm<`y'*100
		    }

	        sum wage, det  
	        count if wage==.
	        
		drop if wage==.  
		rename yyyymm ultimoperiodopago
		  
	        ** 4 Cells for wages **
		xtile xwage4=wage, nquant(4)
                sum wage, det
  		tab xwage4, sum(wage)

	*** STEP 2.3: DEFINE A MEASURE IF A PERSON WAS UNEMPLOYED AT THE TIME OF MARKET START ***
            gen byte unemp9798=((bemployed_1997==0 | bemployed_1997==.)&(bemployed_1998==0 |bemployed_1998==.))	
     	      gen byte unemp97=((bemployed_1997==0 | bemployed_1997==.))


	*** STEP 2.5: DEFINE GENDER AND STATE OF RESIDENCE  ***
            gen byte male=(sexo=="1")
            replace male=. if sexo==""

	    destring c_estado, replace


	*** STEP 2.5: LABEL VARIABLES AND SAVE ***
		label var muni "Postal Codes: Municipio"
		label var age "Age of worker"
		label var xage4 "Age Category of worker: 1 (14-29), 2 (30-39), 3 (40-49), 4 (50+)" /* go back and re-label when final age decision is made */
		label var wage "First recorded daily integrated wage for worker"
		label var xwage4 "Wage quartile of worker"
		label var unemp97 "Worker was unemployed for 1997"
		label var unemp9798 "Worker was unemployed for 1997 and 1998"
		label var total_muni "Total number of account holders in this muni"
            label var yrs_to_ret "Years until the worker reaches 65"


      *** STEP 2.6: REPLACE MISSING EXPECTED WAGES, CONTRIBUTIONS, ETC WITH ZEROS ***
           forvalues y=1997(1)2006  {
             replace capped_expsal_`y'=0 if capped_expsal_`y'==.
             replace expsdi_`y'=0 if expsdi_`y'==.
             replace expdias_`y'=0 if expdias_`y'==.
             replace cs_`y' = 0 if cs_`y'==.
             replace bemployed_`y'=0 if bemployed_`y'==.
               }
               
	*** STEP 2.7: KEEP ONLY VARIABLES WE NEED FOR ANALYSIS ***
        drop  fechanacimiento sexo fechaprimeraafiliacion fechaaltaaforeactual ultimoperiodopago fech_liqtrasp no_switch ///
	fecha_liquid cod_post total_state ipc  estatal* rcv* cuotasocial* 
	compress
	desc

    save "${tempfile}/basedemanddata.dta", replace


*************************************************************************************
*** STEPS 3-4: START LOOP OVER MUNICIPIOS AND CELLS TO ESTIMATE DEMAND PARAMETERS ***
*************************************************************************************


**** STEP 3: SPLIT DATA INTO 20 GROUPS OF CELLS AND LOOP OVER THEM TO CALCULATE COST AND  ***
****	       CREATE DATA SETS NEEDED FOR DEMAND ESTIMATION 				  ***
*********************************************************************************************

    egen cell = group(muni xage4 xwage4 male)
    drop if inception_afore==.		
    save "${tempfile}/basedemanddata.dta", replace

  *** STEP 3.1: Split data into 20 groups to loop over by cell so that data are small enough to calculate cost and estimate demand ***
    sort cell
    xtile set = cell, nq(20)  

  *** STEP 3.1.1: Generating wage, age, balance, and expected days subgroups which we will group by
  
    gen expdias_9798 = expdias_1997 + expdias_1998
    gen rexpdias_9798 = round(expdias_9798,100)    
     save "${tempfile}temp1.dta", replace
    
    keep nss c_estado wage
    save "${tempfile}temp2.dta", replace
   

    clear
    set obs 1
    gen remove = 1
    save "${tempfile}temp_xwage_by_state.dta", replace
  
    use "${tempfile}temp2.dta", clear
    sum c_estado
    local Nmax = r(max)
    forval i = 1(1)`Nmax' {
    use "${tempfile}temp2.dta", clear
    keep if c_estado==`i'
    xtile rwage = wage, nquant(8)
    append using "${tempfile}temp_xwage_by_state.dta"
    save "${tempfile}temp_xwage_by_state.dta", replace
    }
    
    drop if remove==1
    drop remove
    save "${tempfile}temp_xwage_by_state.dta", replace  
     
    use "${tempfile}temp1.dta", clear
    merge nss using "${tempfile}temp_xwage_by_state.dta", keep(rwage) sort
    assert _merge==3
    drop _merge

    gen temp1 = round(age,5)
    gen rage = .
    replace rage = 1 if age<=18
    replace rage = temp1 if age>18
    replace rage = 2 if rage>=55	
    tab rage, m		
    drop temp*

    gen rsar92sum = .
    replace rsar92sum = 1 if sar92sum<500
    replace rsar92sum = 2 if sar92sum>=500 & sar92sum<5000
    replace rsar92sum = 3 if sar92sum>=5000 & sar92sum<20000
    replace rsar92sum = 4 if sar92sum>=20000 & sar92sum!=.   

   *** STEP 3.1.2: Grouping into cells by state, gender, age group, sar92 balance range, approx days worked, and wage quantile
    egen group = group(c_estado male rwage rage rsar92sum rexpdias_9798)  
    bysort group: gen N = _N
    bysort group: gen k = 1 if _n==1
    sum N if k==1, det

   *** STEP 3.1.3: Further dividing larger cells to make groups more similar when possible
 
    gen sgident = .		
    save "${tempfile}temp1.dta", replace
   
    use "${tempfile}temp1.dta", clear
    keep if N<100
    replace sgident = 0
    save "${tempfile}temp2.dta", replace

    use "${tempfile}temp1.dta", clear
    keep if N>=100 & N<200
    bysort group: egen temp = median(wage)
    replace sgident = 1 if wage<=temp
    replace sgident = 2 if wage>temp 
    drop temp
    save "${tempfile}temp3.dta", replace 

    use "${tempfile}temp1.dta", clear
    keep if N>=200 & N<400
    bysort group: egen temp1 = median(wage)
    bysort group: egen temp2 = median(expdias_9798)
    gen temptag = (temp2==0 | temp2==488)	
    replace sgident = 1 if wage<=temp1 & expdias_9798<=temp2 
    replace sgident = 2 if wage<=temp1 & expdias_9798>temp2
    replace sgident = 3 if wage>temp1 & expdias_9798<=temp2
    replace sgident = 4 if wage>temp1 & expdias_9798>temp2 
    replace sgident = 1 if wage<=temp1 & temptag==1
    replace sgident = 3 if wage>temp1 & temptag==1
    drop temp*
    save "${tempfile}temp4.dta", replace
  
    use "${tempfile}temp1.dta", clear
    keep if N>=400 & N<800
    bysort group: egen temp1 = median(wage)
    bysort group: egen temp2 = median(expdias_9798)
    bysort group: egen temp3 = median(sar92sum)
    gen temptag = (temp2==0 | temp2==488)
    gen temptag2 = (temp3==0)   
    gen tempa = (wage<=temp1)
    gen tempb = (expdias_9798<=temp2)
    replace tempb = 1 if temptag==1	
    gen tempc = (sar92sum<=temp3)
    replace tempc = 1 if temptag2==1
    egen tempgroup = group(tempa tempb tempc)
    replace sgident = tempgroup
    drop temp*
    save "${tempfile}temp5.dta", replace
   
    use "${tempfile}temp1.dta", clear
    keep if N>=800 
    bysort group: egen temp1a = median(wage)
    bysort group: egen temp1b = pctile(wage), p(25)
    bysort group: egen temp1c = pctile(wage), p(75)
    bysort group: egen temp2 = median(expdias_9798)
    bysort group: egen temp3 = median(sar92sum)
    gen temptag = (temp2==0 | temp2==488)
    gen temptag2 = (temp3==0)
    gen tempa = (wage<=temp1b)
    replace tempa = 2 if wage>temp1b & wage<=temp1a
    replace tempa = 3 if wage>temp1a & wage<=temp1c
    replace tempa = 4 if wage>temp1c 
    gen tempb = (expdias_9798<=temp2)
    replace tempb = 1 if temptag==1
    gen tempc = (sar92sum<=temp3)
    replace tempc = 1 if temptag2==1
    egen tempgroup = group(tempa tempb tempc)
    replace sgident = tempgroup
    drop temp*
    save "${tempfile}temp6.dta", replace

     use "${tempfile}temp2.dta", clear
    forval i = 3(1)6  {
    append using "${tempfile}temp`i'.dta"
    }

     drop N k
    egen newgroup = group(group sgident)
    bysort newgroup: gen N = _N
    bysort newgroup: gen k = 1 if _n==1
    drop N k

    forval y = 1997(1)2006 {	
    bysort newgroup: egen gcapped_expsal_`y' = mean(capped_expsal_`y')
    bysort newgroup: egen gcs_`y' = mean(cs_`y')         
    }

    drop capped_expsal* expdias_19* expdias_20* cs* group		
    forval y = 1997(1)2006 {
    rename gcapped_expsal_`y' capped_expsal_`y'		
    rename gcs_`y' cs_`y'
    }

    forvalues set = 1(1)20 {
      preserve
      keep if set==`set'
      save "${tempfile}inception_set_`set'_predcost.dta", replace
      restore
     }





   *******************************
   **** CELL LOOP STARTS HERE ****
   *******************************
   *** STEP 3.2: Estimate costs in each afore and demand looping over demoraphic cells ***
   forvalues set = 1(1)20 {

   use "${tempfile}inception_set_`set'_predcost.dta", clear
      set more off 
      sum cell
      global N_last_cell=r(max)
      global N_first_cell=r(min)

   local i = 1
   display "STARTING THE `i' CELL OF SET `set' OF CELLS"

   forvalues c=$N_first_cell(1)$N_last_cell  {
    
     use "${tempfile}inception_set_`set'_predcost.dta", clear
     keep if cell==`c'
 	 
      count
      local n=r(N)
      display "CELL `c' HAS `n' PEOPLE IN IT"
      
      if `n'>500 {
       
      cross using "${infile}inceptionfees_wtenure.dta"
      sort nss afore_code

        rename flowfee flow1997  
        rename n_1 flow1998
        rename n_2 flow1999
        rename n_3 flow2000
        rename n_4 flow2001
        rename n_5 flow2002
        rename n_6 flow2003
        rename n_7 flow2004
        rename n_8 flow2005
        rename n_9 flow2006
  
      *** Now generate the future value to retirement account of each year's contributions given fee structure
        forvalues y=1997(1)2006 {    
            gen temp1 = `y'-1996		
            gen yrs_disc=max(yrs_to_ret+1-temp1,0)	
      	gen temp=0
      	replace temp=1 if (yrs_to_ret>=temp1)	
 	   
 	      gen contribution_`y'=temp*(capped_expsal_`y'*(0.065-flow`y'/100)+cs_`y')*(1+((.05-balfee/100)/2))*(1.05-balfee/100)^(yrs_disc-1)   /* how much the amount your contributing will be worth in 1997 pesos at retirement */
      	     	
      	drop temp temp1 yrs_disc
     	     }
                  
        egen tenyear_balance_fees=rowtotal(contribution_1997-contribution_2006)

     	  drop contribution_1997-contribution_2006
    	    
    	  forvalues y=1997(1)2006 {
          gen temp1 = `y'-1996
          gen yrs_disc=max(yrs_to_ret+1-temp1,0)
          gen temp=0
          replace temp=1 if (yrs_to_ret>=temp1)
            
          gen contribution_`y' = temp*(capped_expsal_`y'*.065 + cs_`y')*(1.025)*(1.05)^(yrs_disc-1)
 	       	              
          drop temp temp1 yrs_disc
          }

        egen tenyear_balance_nofees=rowtotal(contribution_1997-contribution_2006)
    	  drop contribution_1997-contribution_2006
          
        gen flow_costs=tenyear_balance_nofees - tenyear_balance_fees	 
        gen balance_costs= sar92sum*(1.05)^(yrs_to_ret) - sar92sum*(1.05-balfee/100)^(yrs_to_ret)   
 
      *** Now generate total costs
        gen total_management_cost=flow_costs+balance_costs

        forvalues y=1997(1)2006 {
          gen temp1 = `y'-1996
          gen yrs_disc=max(yrs_to_ret+1-temp1,0)
          gen temp=0
          replace temp=1 if (yrs_to_ret>=temp1)
              
          gen dcostdflow_`y'=temp*(capped_expsal_`y'/100)*((1.05-balfee/100)/2)*(1.05-balfee/100)^(yrs_disc-1)
	   
	   drop temp temp1 yrs_disc
         }

        egen dcostdflow=rowtotal(dcostdflow_1997-dcostdflow_2006)

        drop dcostdflow_*

        forvalues y=1997(1)2006 {
          gen temp1 = `y'-1996
          gen yrs_disc=max(yrs_to_ret+1-temp1,0)
          gen temp=0
          replace temp=1 if (yrs_to_ret>=temp1)
 
          gen dcostdbal_`y'=temp*(capped_expsal_`y'*(0.065 -flow`y'/100)+cs_`y')*(1+(.05-balfee/100)/2)*(1/100)*(yrs_disc-1)*(1.05-balfee/100)^(yrs_disc-2)  ///
                              + temp*(capped_expsal_`y'*(0.065 -flow`y'/100)+cs_`y')*(1/200)*(1.05-balfee/100)^(yrs_disc-1)
        drop temp temp1 yrs_disc  
        }

       
        gen dcostdbal_start=(1/100)*yrs_to_ret*sar92sum*(1.05-balfee/100)^(yrs_to_ret-1) 
        egen dcostdbal=rowtotal(dcostdbal_1997-dcostdbal_start)
        drop dcostdbal_1997-dcostdbal_start
        rename total_management_cost cost
        gen chosen = 0
        replace chosen = 1 if inception_afore==afore_code
       
      
      keep nss cell afore_code dcostdbal dcostdflow cost wage sar92sum age chosen muni xwage4 xage4 male 
      compress
       
          if `i' ==1 {
		  save "${tempfile}demanddata_`set'_predcost.dta", replace
                 }
           
          else {
		   append using "${tempfile}demanddata_`set'_predcost.dta"
                   sum cell
                   disp "************ FINISHING CELL = `c' ************************"
		   save "${tempfile}demanddata_`set'_predcost.dta", replace
		} 	
	       
	       local i = `i'+1
	       
     	}   /* end of the cells loop */
     


}	/* end of the set loop */


    **** END OF CELL LOOP ****
}
   
***********************************************************************************
*** STEP 4: NOW LOOP OVER DATA SETS AND CELLS TO ESTIMATE DEMAND PARAMETERS     ***
***********************************************************************************

   
  set more off  
  forvalues set = 1(1)20 {

    use "${tempfile}demanddata_`set'_predcost.dta", clear
    xi i.afore_code, prefix(_A)
    gen cost_wage = cost*wage 
    save "${tempfile}demanddata_`set'_predcost.dta", replace
    }
      
       

  *** STEP 4.2: START CONDITIONAL LOGIT ESTIMATION LOOP ***

    forvalues set = 1(1)20 {

    use "${tempfile}demanddata_`set'_predcost.dta", clear
      set more off 
      sum cell
 
      local i = 1
    
      levelsof cell, local (levels)
     
      foreach c of local levels {

      display "STARTING THE `c' CELL OF SET `set' OF CELLS"
      
         use "${tempfile}demanddata_`set'_predcost.dta", clear
         keep if cell==`c'
       
         disp "************ CELL = `c' ************************"
         disp "************* N PEOPLE IN THIS CELL *********************"
         count if afore_code==516
		local n=r(N)
         disp "*********************************************************"
         gen float prob_ij=.
         
         /* by construction above, all of these cells have 200 or more in them so this is redundant */
	   if `n'>=200 {
          gen byte toosmallcell=0 

          ** Make afore code 548 the outside good - has min share of .007 and mean share of 10.868 **
          rename _Aafore_cod_548 _Aafore_cod_0
          gen byte _Aafore_cod_510=(afore_code==510)
	  
	  clogit chosen cost cost_wage _Aafore_cod_5*, group(nss) iterate(30)   
           
          gen byte flag=e(converged)
          label var flag "indicator for whether the estimation converged"

            if e(converged)==1 {
 

             predict prob if e(sample), pc1  
             replace prob_ij=prob

             drop prob

		gen bcost=_b[cost]
		gen bcost_wage=_b[cost_wage]
	        gen bA510 = _b[_Aafore_cod_510]
		gen bA512 = _b[_Aafore_cod_512]
		gen bA514 = _b[_Aafore_cod_514]
		gen bA516 = _b[_Aafore_cod_516]
		gen bA530 = _b[_Aafore_cod_530]
		gen bA532 = _b[_Aafore_cod_532]
		gen bA534 = _b[_Aafore_cod_534]
		gen bA536 = _b[_Aafore_cod_536]
		gen bA538 = _b[_Aafore_cod_538]
		gen bA540 = _b[_Aafore_cod_540]
		gen bA542 = _b[_Aafore_cod_542]
		gen bA544 = _b[_Aafore_cod_544]
		gen bA546 = _b[_Aafore_cod_546]
		*gen bA548 = _b[_Aafore_cod_548]
		gen bA550 = _b[_Aafore_cod_550]
		gen bA552 = _b[_Aafore_cod_552]
		gen bA554 = _b[_Aafore_cod_554]
               
               }  /* closes convergence loop */
                
             } /* closes cell size n>200 loop */
       
      else {
		gen byte toosmallcell=1
       } 
	*** closes the cell size loop

           
            compress 
            
           if `i'==1 {		
			 save "${tempfile}demandestimates_`set'_predcost.dta", replace

                 }
           
           else {
           	  
		   append using "${tempfile}demandestimates_`set'_predcost.dta"
               	   disp "************ FINISHING CELL = `c' ************************"
                   save "${tempfile}demandestimates_`set'_predcost.dta", replace
		} 	
		
	local i = `i'+1      

    	}     		/* closes loop over cells */
  }			/* closes loop over sets */




*********************************************************************************************
*** STEP 5: USE DEMAND PARAMETERS TO CALCULATE ELASTICITIES AND FIRST-ORDER CONDITIONS    ***
***         WITH RESPECT TO FLOW FEE AND BALANCE FEE                                      ***
*********************************************************************************************

  *** STEP 5.1 CALCULATE THE COMPONENTS OF THE FIRST ORDER CONDITIONS AND ***
  ***          DEMAND ELASTICIITES FOR EACH PERSON			  ***
  ***************************************************************************
  clear
  set mem 27g
  forvalues set = 1(1)20 {
  use "${tempfile}demandestimates_`set'_predcost.dta", clear


    table afore_code, c( mean prob_ij sd prob_ij mean chosen)   
  
    ** Choice elasticity wrt cost = dprob/dcost * cost/prob  **
    ** dprob/dcost = prob*(1-prob)*(bcost + bcost_wage*wage) **
  
    gen elasticity = (bcost + bcost_wage*wage)*prob*(1-prob)*(cost/prob)
    tab afore_code, sum(elasticity)
  
    gen byte count=`set'
  
    if count==1 {
      keep nss muni sar92sum xage4 xwage4 male cell wage afore_code cost chosen prob_ij bcost bcost_wage bA510-elasticity
      compress 
      count
      save "${tempfile}elasticities_predcost.dta", replace
      }
     else  {
      keep nss muni sar92sum xage4 xwage4 male cell wage afore_code cost chosen prob_ij bcost bcost_wage bA510-elasticity
      compress 
      count
      append using "${tempfile}elasticities_predcost.dta"
      count
      save "${tempfile}elasticities_predcost.dta", replace
      }    
   }    

   *** Label variables and save ***
   label var male "Male =1, Female = 0"
   label var cost "Predicted cost in Afore j"
   label var chosen "Indicator for person i's chosen Afore"
   label var prob_ij "Predicted probability person i chooses Afore j"
   label var bcost "Person i's estimated preference for expected cost"
   label var bcost_wage "Person i's estimated preference for expected cost interacted with wage"
   foreach a in 510 512 514 516 530 532 534 536 538 540 542 544 546 550 552 554 {
	label var bA`a' "Estimated mean preference for Afore `a'"
	}
   label var elasticity "Estimated elasticity for person i for Afore j"
   
   save "${tempfile}elasticities_predcost.dta", replace
   sum
      
   


****************************************************************************************
*** STEP 6: PREP DATA FOR ESTIMATING THE RELATIONSHIP BETWEEN PRICE SENSITIVITY, 
***         BRAND VALUE AND AGENTES USING ESTIMATED UTILITY PARAMETERS AND INSTRUMENTS   
***	    FOR AGENTES
****************************************************************************************

    use "${tempfile}elasticities_predcost.dta", clear
   
    *generate average cost of people in your muni but not in your demographic cell*
    gen int demogroup=xwage4*100+xage4*10+male

    *reshape deltas long ***
    gen delta=.
    foreach afore in 510 512 514 516 530 532 534 536 538 540 542 544 546 550 552 554 {
       replace delta=bA`afore' if afore_code==`afore' 
      }
    drop bA5*

    egen mktshrC=mean(chosen), by(muni demogroup afore_code)  
    egen mktshrM=mean(chosen), by(muni afore_code)            


    *** MAKE AN INSTRUMENT THAT IS THE AVERAGE COST OR THE AVERAGE WAGE OF PEOPLE NOT IN 
    *** YOUR DEMOGRAPHIC CELL BUT IN YOUR SAME MUNICIPIO ***
    bysort muni: gen N=_N
    foreach var in cost wage {	
      egen temp1=mean(`var'), by(muni)
	egen temp2=total(`var'/N), by(muni demogroup)
	gen iv`var'=temp1-temp2
	
	drop temp1 temp2 
	}

    drop N
    bysort muni demogroup: egen Ncell=sum(chosen) 
    bysort muni: egen Nmuni=sum(chosen) 
	
    ** generate average wage of people in your cell
    egen cellwage=mean(wage), by(muni demogroup)

    label var ivcost "Instrument: Ave cost by for people in your Muni but not in your Cell"
    label var ivwage "Instrument: Ave wage for people in your Muni but not in your Cell"
    label var cellwage "Instrument: Ave wage of people in your Cell"
    label var Nmuni "NIMSS in Municipio"
    label var Ncell "NIMSS in Cell"
    
    
    *** MAKE AN INSTRUMENT THAT IS THE AVERAGE COST BY AFORE FOR OTHER PEOPLE NOT IN
    *** YOUR DEMOGRAPHIC CELL, BUT IN YOUR SAME MUNICIPIO *** 
    egen temp1=mean(cost), by(muni afore)
    bysort muni afore: gen N=_N
    egen temp2=total(cost/N), by(muni afore demogroup)

    set more off	
    gen ivcost2=temp1-temp2
    label var ivcost2 "Instrument: Ave cost by Afore for people in your Muni but not in your Cell"
    rename temp1 meancostM
    
    gen temp1=(sar92sum>0) 
    egen s92iv1=mean(temp1), by(muni demogroup)
    egen s92iv2=mean(temp1), by(muni)
    
    label var s92iv1 "Instrument: fraction in muni demo w/ no sar92 bal"
    label var s92iv2 "Instrument: fraction in muni w/ no sar92 bal"
    
    drop temp2 temp1 N
    egen temp1=mean(cost), by(muni demogroup afore)
    rename temp1 meancostC
    
    save "${tempfile}tempcollapse2_predcost.dta", replace
	  
    use "${tempfile}tempcollapse2_predcost.dta", clear
      bysort muni cell afore: gen n=_n
      keep if n==1
      drop n
    save "${tempfile}tempcollapse3_predcost.dta", replace

  ***Merge on Agentes and instruments from INEGI data, these get merged by afore and muni ****
    use "${tempfile}tempcollapse3_predcost.dta", clear
      merge m:1 muni afore_code using "${infile}CensusAgentes_IVs.dta", ///
      keepusing (muni afore_code agentes_level n_imss ISSSTE sdloc_ISSSTE)
      tab _merge  
      drop if _merge ==2
      drop _merge
      *** generate agentes per 1000 imss clients ***
      gen agentes_perimss=agentes_leve/n_imss
      gen agentes_percell = agentes_level/Ncell
      egen agentes_level_total=total(agentes_level), by(muni demogroup)
      egen agentes_perimss_total=total(agentes_perimss), by(muni demogroup)
      egen agentes_percell_total=total(agentes_perimss), by(muni demogroup)
      
  ***Make measures of agentes for outside Afore - - Afore 510 ***
    foreach var in agentes_perimss agentes_level {
      gen temp=`var' if afore_code==548
      egen `var'_548=min(temp), by(muni)
      drop temp
     }

   drop nss chosen
   save "${tempfile}temp_betas&ivs.dta", replace
   sum
   
   cap log close




