%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%FUNCTION: Best-response Calculations %%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function creates BR-calculation based on the horizon fit given
% Arguments
% horiz - horizon fit
% adv - advertising-level coefficients ; 1 = base and 2 = neutral
% sens - price sensitivity level ;  1 = base and 2 = elastic
% govt - govt firm fee ; 1 = base and 2 = government competitor 
% 
% Output:
% Data - matrix of (1) flow fee (2) balance fee (3) expected shares and (4) revenue
%
% Remarks: 
% (1) Cost/Profits are in present-value terms in this code 
% (2) This program calculates the equilibrium fees when 
%     time horizons vary. We calculate the horizon that best
%     fits the observed fees at each BR-iteration.
% (3) We use a discount rate of (1/1.05) for both the firms and the agents
% (4) Note that discounting back depends on the horizong (i.e.,
%     firms discount cost at (1/1.05).^min(retirement yrs, horizon).
% (5) This program calls worker station. 
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [ff bb] = calc_equil_fees(horiz,adv,sens,govt)

global dirname dirname_pre dirname_output flowcap balcap gridsize ns matsize

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Step I: Prepare calculations for the logit denominator
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


[x,y]=meshgrid( 0:gridsize:flowcap , 0:gridsize:balcap);
n1=length(x(:,1));
n2=length(x(1,:));

load newdata.mat;


discount=[0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 -.05 -.05 -.05 -.05 -.05 -.05 -.05 -.05 -.05;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 -0.02 -0.02 -0.02 -0.02 -0.02;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 0 0 0 0 0;
       0 0 0 0 0 -0.02 -0.02 -0.02 -0.02 -0.02;
       0 -0.02 -0.01 -0.01 -0.01 -0.01 -0.01 0 0 0];

   
discount=discount/100;
tenure=cumsum(discount);
nj = size(discount,1);
betas=betas_m(:,:,adv);

% choose price sensitivity counterfactual

lambda_temp = betas(:,1) + betas(:,2).*wage;


if sens==1 
    
    lambda   = lambda_temp  ; % ns vector of lambda_i

else

    lambda   = lambda_temp ...
        -std(lambda_temp).*(lambda_temp>prctile(lambda_temp,75))  ; % ns vector of lambda_i   
        
end

    lambda_m    =  kron(ones(1,nj),lambda);

%Define 10 years out index for annual cost calculation
temp=[1997 1998 1999 2000 2001 2002 2003 2004 2005 2006]-1996;
nt=size(temp,2);   %number of years going out - 10 years amortization %
yrs_to_ret_m=yrs_to_ret*ones(1,nt);   % ns x nt matrix %
yrs_disc=max(yrs_to_ret_m+1-ones(ns,1)*temp,0); % defines the disount level, 0 if you already reached retirement %
                                                % ns x nt matrix of discount levels for each person in each year %
indicator = (yrs_to_ret_m>=ones(ns,1)*temp);  % ns x nt matrix indicating if person i is still non-retired at time t%
capped_salary1     = indicator.*capped_salary; %ns x nt .* ns x nt
cs1     = indicator.*cs_alt;
contribution2 = sum(( 0.065*capped_salary1+cs1 )  .*  1.025  .*  (1.05.^(yrs_disc-1)),2); % an ns x nt matrix %
deltapar=betas(:,3:end); % prod differentiation parameter

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% Step II: Initialize Starting values and worker pools
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

ff=fees(:,2)/100;  % Initialize XXI at actual fee levels
bb=fees(:,3)/100;  % Initialize XXI at actual fee levels

% Testing with different starting values
% Comment the following 2 lines for the standard script
%ff = randsample(0:gridsize:flowcap,length(ff))';
%bb = randsample(0:gridsize:balcap,length(bb))';
% Step II.a choose government player counterfactual type - set iteration
% and horizon
% type and government competitor's fee level

if govt==1 
    
    firmiter = [1:17];

else
    
    firmiter = [1:3, 5:17];
    ff(4)=0;
    bb(4)=0.001;
end


c_flow=zeros(nj,10);
c_bal=zeros(nj,10);
flowcosts=zeros(ns,nj);
balancecosts=zeros(ns,nj);
%parpool

% Step II.b set horizong level

h=horiz; 



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Step III: Sequential BR iteration
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Step III.A initialize tolerance and specifiy the tolerance level

halt = 0;
iter = 0; 
while halt == 0

	flowfee   = ff;
	balancefee = bb;
    
    % Step III.B: Calculate profit on the grid point and maximize profit by
    % horizon
    
    for m=firmiter

        
	   		%CREATING MATRIX OF FLOW FEES USING ASSUMPTIONS
      		 flowfeem=zeros(nj,nt);   %nafore x nyears to retirement%
     		 flowfeem(:,1)=flowfee;       %base flow fee in first year%
     		 
     		 for j=2:nt
       		 	 flowfeem(:,j)=flowfeem(:,j-1) + discount(:,j);  %replace flow fee in each year with flow fee - tenure discount %
       
       		 end
       
       		 flowfeem=max(flowfeem,0);  %there shouldn't be any negative flow fees%
          
    
   		 	for j= 1:nj
         		yr_contr             = capped_salary1.* (  0.065-kron( ones(ns,1),flowfeem(j,:))  );
           		contribution1         = indicator.*(  yr_contr +cs1  )  .* (1+(0.05-balancefee(j))/2) .* (1.05-balancefee(j)).^(yrs_disc-1);
           		flowcosts(:,j)        = contribution2-sum(contribution1,2); %ok  
           		balancecosts(:,j)     = sar92sum .* (  1.05.^yrs_to_ret- (1.05-balancefee(j)).^yrs_to_ret ); %ok
    		end
     
       		cost   = (1/1.05).^kron(ones(1,nj),yrs_to_ret).*min(kron(ones...
                (1,nj),contribution2+sar92sum.*(1.05.^yrs_to_ret)),flowcosts+balancecosts);
      	
	   		deletem=ones(nj,1);
       		deletem(m)=0;
       		deletem=logical(deletem); 
       		otherdenominator  = sum(exp( (lambda_m(:,deletem).*cost(:,deletem) + deltapar(:,deletem)) ),2);
       		
       		if (any(isinf(otherdenominator))) % Check for inf values in logit denominator
           		disp('Warning: Inf values in logit denominator!!! Please rescale the problem for numerical accuracy')
       		end
    
	 		
                
            profit=zeros(n1,n2);
                 
                parfor j=1:floor(ns/matsize)
                    globalBridge(dirname,dirname_pre,dirname_output,flowcap,balcap,gridsize,ns,matsize);

                    index=(j-1)*matsize+1:j*matsize;
                    
                    
                    %% Load revenue grid points
                    
                    if m~=9 && m~=12 && m~=16 && m~=17
          		   
	 	 				data=parload(fullfile(dirname_pre...
                            ,strcat(num2str(1),'rev',num2str(j),'h',num2str(h(m)),'.mat')));
                        rev=data;        
                    else
	 	 				
                    	data=parload(fullfile(dirname_pre...
                            ,strcat(num2str(m),'rev',num2str(j),'h',num2str(h(m)),'.mat')));
                        rev=data;
	 	 				 	 				
                    end
                    
                    %% Load numerator grid points
                    
                    %% Load numerator grid points depending on counterfactual type
                    
                    if adv==1 && sens==1
                        
                        data=parload(fullfile(dirname_pre,...
                            strcat(num2str(m),'numer',num2str(j),'.mat')));
                        
                    elseif adv==2 && sens==1
                        
                        data=parload(fullfile(dirname_pre,...
                            strcat(num2str(m),'cnumer',num2str(j),'.mat')));
                        
                        
                    elseif adv==1 && sens==2
                        
                        data=parload(fullfile(dirname_pre,...
                            strcat(num2str(m),'snumer',num2str(j),'.mat')));
                        
                    else
                        
                        data=parload(fullfile(dirname_pre,...
                            strcat(num2str(m),'csnumer',num2str(j),'.mat')));
                    end
                                     
                    
                    
                    
                    numer=data;
                    
                    %%Calculate expected profit by horizon
                    otherdenominator_m=reshape(kron(otherdenominator(index)',ones(n1,n2)),[n1,n2,matsize]) ;
                    ownprob = numer./(numer+otherdenominator_m);
                    profit=profit+sum(ownprob.*rev,3);
       				   	
                end
                
             %% Load revenue grid points
                    
                if m~=9 && m~=12 && m~=16 && m~=17
          		   
                    data=parload(fullfile(dirname_pre...
                            ,strcat(num2str(1),'rev',num2str(floor(ns/matsize)+1),'h',num2str(h(m)),'.mat')));
                    rev=data;
                                               
                else
	 	 				
                    data=parload(fullfile(dirname_pre...
                            ,strcat(num2str(m),'rev',num2str(floor(ns/matsize)+1),'h',num2str(h(m)),'.mat')));
                    rev=data;
	 	 				 	 				
                end
                
                   %% Load numerator grid points
               index=floor(ns/matsize)*matsize+1:ns;       
     
               %% Load numerator grid points depending on counterfactual type
                    
               if adv==1 && sens==1
                        
                   data=parload(fullfile(dirname_pre,...
                      strcat(num2str(m),'numer',num2str(floor(ns/matsize)+1),'.mat')));
                        
               elseif adv==2 && sens==1
                        
                    data=parload(fullfile(dirname_pre,...
                       strcat(num2str(m),'cnumer',num2str(floor(ns/matsize)+1),'.mat')));
                        
               elseif adv==1 && sens==2
                        
                    data=parload(fullfile(dirname_pre,...
                            strcat(num2str(m),'snumer',num2str(floor(ns/matsize)+1),'.mat')));
                        
               else
                        
                    data=parload(fullfile(dirname_pre,...
                      strcat(num2str(m),'csnumer',num2str(floor(ns/matsize)+1),'.mat')));
               end
                   
                    
               numer=data;
                    
               %%Calculate expected profit by horizon
               otherdenominator_m=reshape(kron(otherdenominator(index)',ones(n1,n2)),[n1,n2,ns-floor(ns/matsize)*matsize]) ;
               ownprob = numer./(numer+otherdenominator_m);
               profit=profit+sum(ownprob.*rev,3);
                
               
                      	 	
		    	[C I]=max(profit(:));
    			flowfee(m)=x(I);
      	 	balancefee(m)=y(I);
      
            
    end

	
	toleps= sum(abs(flowfee-ff)+abs(balancefee-bb))
	ff=flowfee;
	bb=balancefee;
    iter = iter + 1;
    
    % record first 3 iteration in a matrix
    toleps_m(iter) = toleps;
    
    
    %% define halt - we stop the iteration if the difference is less than .001
    %% In one calculation the BR iteraton osscilates but the tolerance level is still low
    %% at .0043. We halt the BR and use this approximated BR
    
   
    
    if toleps < .0001 
        halt = 1;
    else
        if iter >=3 
            dummy_iter = toleps_m(iter-2)-toleps_m(iter);
            if dummy_iter == 0
                halt = 1;
                disp('Warning: BR iteration oscillating and halted. Please verify that the equilibrium is well approximated')
                [flowfee,ff]  
                [balancefee,bb]
                toleps
            else
                halt =0 ;
            end 
        else
            halt = 0;
        end
    end
    
    
 
end



end
