
********************* TABLES FOR PUBLICATION DO FILE ***************************
* This do file creates the final tables, ready for the press, for the paper: 
* "Sales Force and Competition in Financial Product Markets: The Case of 
* Mexico’s Social Security Privatization"
* by 
* Justine Hastings (justine_hastings@brown.edu),
* Ali Hortaçsu (hortacsu@uchicago.edu), and
* Chad Syverson(chad.syverson@chicagobooth.edu)
*
* March, 2017
*
********************************************************************************





*----------------------------- PRELIMINARIES ----------------------------------*
clear*
capture clear matrix
set matsize 600
set more off, perm
set more off
*
global sysdate = c(current_date)
*
* FOR REPLICATION: Change the following path to the Master folder path:
global Path "/share/HHS/final_files/Master"

* The rest is automatic. The Master file should contain MatlabInputs and 
* MatlabOutputs. The formatted tables will be written in the folder
* "Master/MatlabOutputs/TablesReadyForPub"

cd "$Path"
capture mkdir "$Path/MatlabOutputs/StataAux" , public   // Will be erased at the end 
capture mkdir "$Path/MatlabOutputs/TablesReadyForPub"
global Aux "$Path/MatlabOutputs/StataAux"
global Ready "$Path/MatlabOutputs/TablesReadyForPub"

*


*********************  INDEX ****************************
*							*
*		I   -  REMINDERS 			*
*		II - TABLE VII				*
*		III  -  TABLE VIII			*
*		IV -  TABLE IX				*
*		V  -  APPENDIX TABLE III		*
*							*
*********************************************************


*-------------- I  -  REMINDERS -----------------------------------------------*
* In the Matlab main script, the different models can be identified like this: 
* Advertising-level coefficients ; 1 = base and 2 = neutral
* Price sensitivity level ;  1 = base and 2 = elastic
* Govt firm fee ; 1 = base and 2 = government competitor 


* This do file imports the following tables created by Matlab as raw data:
* - "$Path/MatlabOutputs/Table8Counterfactual.csv"
* - "$Path/MatlabOutputs/Table8.csv"
* - "$Path/MatlabOutputs/TableIX.csv"
* - "$Path/MatlabOutputs/Table9.csv"
* - "$Path/MatlabOutputs/Table_addendum.csv"
* - "$Path/MatlabOutputs/costbydemotable2_updated.csv"
* - "$Path/MatlabOutputs/Table10.csv"


*-------------- II -  TABLE VII ------------------------------------------------*
*SUMMARY OF OUTCOMES FOR DEMAND AND SUPPLY-SIDE POLICIES

* Table VII, col 1 is column 11 on table costbydemotable2_updated.csv. The csv
* has a header. In the csv, col 11 is labeled cont6d.
* The table already has headers and row names

import delimited using "$Path/MatlabOutputs/costbydemotable2_updated.csv",  clear

* The row for All is not in this table, but it can be recovered from it:
keep group cont6c cont6d samplesize base
sum cont6d [fweight = samplesize]
global All = r(mean)

*drop samplesize

* Before I add a row, this auxiliary variable will help me sort the table aftewards
gen n = _n  

* Add the "All" row
set obs 7
replace group = "All" in 7
replace cont6d = $All in 7
replace n = 0 in 7
replace samplesize = 80229 in 7

* Sort so All is at the beginnig
sort n
drop n

* Add the word "workers" after Young and Old:
replace group = "Young workers" in 6
replace group = "Old workers" in 7

* Label cols by changing var names
rename cont6d Pct_change_tot_cost
rename cont6c new_cost

* To get Average Savings in pesos Per Capita, multiply base cost by % change and
* divide by sample size. 


* Base is the expected cost / 1000000
gen base_per_cap = base * 1000000 / samplesize

gen Avg_Save_Pesos_Per_capita = - base_per_cap * Pct_change /100

drop base base_ new_cost

* Gen last column:
gen Min_Pension_equiv_per_cap_year = Avg_Save_Pesos_Per_capita/(580*12)

* Fill in the values for "All"
sum Avg [fweight = samplesize]
global All = r(mean)
replace Avg = $All in 1

sum Min [fweight = samplesize]
global All = r(mean)
replace Min = $All in 1


* Export it to csv
export delimited using "$Ready/TableVII.csv",  replace



*-------------- III - TABLE VIII -----------------------------------------------*
* SUMMARY OF SIMULATION RESULTS WITH DISCONTINUOUS RESPONSES TO GOVERNMENT COMPETITOR
*
*Table VIII in the paper has 4 columns: 
* Col 1: has the Base Model (ffee and bfee for the government competitor and 
*	 its simulated share)
* Col 2: Base model with Government Competitor, caps at (2,2)
* Col 3: Base model with Government Competitor, caps at (3.2,5)
* Col 4: Neutral agents model with Government Competitor, caps at (3.2,5)

* In terms of csv tables in the MatlabOutputs folder:
* Col 1 = col 1 of Table8Counterfactual.csv;
* Col 2 = col 2 of Table8Counterfactual.csv;
* Col 3 = col 2 of Table8;
* Col 4 = col 4 of Table8.

* Note: col 1 is the same in both tables 8 and 8 counterfactual.

* Import cols 1 and 2 from Table8Counterfactual.csv and save them
import delimited c1 c2 using "$Path/MatlabOutputs/Table8Counterfactual.csv", colrange(1:2) clear
gen n = _n
save "$Aux/Table8Part1.dta", replace 

* Import cols 2 and 4 from Table8.csv and merge them with Part1
import delimited c3 aux c4 using "$Path/MatlabOutputs/Table8.csv", colrange(2:4) clear
drop aux
gen n = _n

* Merge them, and order them
merge 1:1 n using "$Aux/Table8Part1.dta", nogen
drop n
order c* , alphabetic
save "$Aux/TableVIII.dta", replace

* Only rows 7:end of Table8Counterfactual is multiplied by 100 for readability.
* I will multiply everything else, so it reads as %.
forvalues t = 1/4 {
	replace c`t' = 100*c`t'
}

* And revert the last 6 rows of col2
replace c2 = c2/100 if _n >= 7  

*Now everything is in percentages


* Label rows by adding an extra variable called "aux_labels"
gen aux_labels = ""
order a c*, alphabetic


replace aux_labels = "XXI flow fee" in 1
replace aux_labels = "XXI balance fee" in 2
replace aux_labels = "XXI simulated share" in 3
replace aux_labels = "Market Share of Afores Pricing at Cap" in 4
replace aux_labels = "Percent of Afores Pricing at Cap" in 5
*Percentage change in management costs
replace aux_labels = "All" in  6
replace aux_labels = "Low-income" in 7
replace aux_labels = "High-income" in 8
replace aux_labels = "Male" in 9
replace aux_labels = "Female" in 10
replace aux_labels = "Young workers" in 11
replace aux_labels = "Old workers" in 12

* Label cols by changing var names
rename c1 BaseModel
rename c2 Base_Cap_at_200_200
rename c3 Base_Cap_at_320_500
rename c4 Neutral_Cap_at_320_500

* Export it to csv
export delimited using "$Ready/TableVIII.csv" , replace



*-------------- IV - TABLE IX ------------------------------------------------*
* SUMMARY OF OUTCOMES FOR DEMAND AND SUPPLY-SIDE POLICIES

* Table IX is composed by:
* Col 1: Increased sensitivity (sens = 2, elasticity = 1, govt = 1)
* Col 2: + Govt Competitor (sens = 2, elasticity = 1, govt = 2)
* Col 3: + Neutral Agents (sens = 2, elasticity = 2, govt = 2)

* Table IX corresponds to TableIX.csv
import delimited c1 c2 c3 using "$Path/MatlabOutputs/TableIX.csv", colrange(1:3) clear

* Again, multiply everything by 100, so it reads as %.
forvalues t = 1/3 {
	replace c`t' = 100*c`t'
}

* Label rows by adding an extra variable called "aux_labels"
gen aux_labels = ""
order a c*, alphabetic

replace aux_labels = "Percent of Afores Pricing at Cap" in 1
replace aux_labels = "Market Share of Afores Pricing at Cap" in 2

*Percentage change in management costs
replace aux_labels = "All" in  3
replace aux_labels = "Low-income" in 4
replace aux_labels = "High-income" in 5
replace aux_labels = "Young workers" in 6
replace aux_labels = "Old workers" in 7
replace aux_labels = "Male" in 8
replace aux_labels = "Female" in 9

* Label cols by changing var names
rename c1 Increased_Elast_4_most_inelast
rename c2 Plus_gov_comp
rename c3 Plus_neutral_agents


* Export it to csv
export delimited using "$Ready/TableIX.csv",  replace


*-------------- VI - APPENDIX TABLE III ---------------------------------------* 
*FITTED TIME HORIZONS 

* Table9.csv + Table10.csv corresponds exactly to Appendix Table III.  

* This table corresponds exactly to Table9.csv from cols 1 through 9.
* Col 10 - Fitted time horizon = col 1 of Table10.csv
* Col 11 - Observed time horizon = col 2 of Table10.csv
* Row 18 - Has correlations of model vs observed

* Part 1 = Table9.csv
import delimited using "$Path/MatlabOutputs/Table9.csv",  clear
gen n = _n
save "$Aux/AppendixTableIXPart1.dta", replace 

* Import cols 1 and 2 from Table10.csv and merge them with Part1
import delimited w10 w11 using "$Path/MatlabOutputs/Table10.csv",  clear 
gen n = _n

* Merge them, and order them
merge 1:1 n using "$Aux/AppendixTableIXPart1.dta", nogen
drop n
order v* w*, alphabetic


* Multiplied cols 1-9 by 100 for readability.
* I will multiply everything else, so it reads as %.
foreach var of varlist v1-v9 {
	replace `var' = 100 * `var'
}

* Replace the last row with missing values
drop if _n == _N
set obs 18

* Create the correlations at the bottom of the table:
* Col 4
corr v1 v4
replace v4 = round(r(rho),0.01) if _n == _N 

* Col 5
corr v2 v5
replace v5 = round(r(rho),0.01) if _n == _N 

* Col 6
corr v3 v6
replace v6 = round(r(rho),0.01) if _n == _N  

* Col 7
corr v1 v7
replace v7 = round(r(rho),0.01) if _n == _N 

* Col 8
corr v2 v8
replace v8 = round(r(rho),0.01) if _n == _N 

* Col 9
corr v3 v9
replace v9 = round(r(rho),0.01) if _n == _N 

* Col 10
corr w10 w11
replace w10 = round(r(rho),0.01) if _n == _N 

* Label rows by adding an extra variable called "aux_labels"
gen aux_labels = ""
order v1 aux_, alphabetic

replace aux_labels = "GenesisMetropolitan" in 1 
replace aux_labels = "Zurich" in 2
replace aux_labels = "Tepeyac" in 3 
replace aux_labels = "XXI" in 4
replace aux_labels = "Banorte" in 5  
replace aux_labels = "Dresdner(AllianzHSBC)" in  6
replace aux_labels = "Profuturo" in  7
replace aux_labels = "AtlanticoPromex" in 8  
replace aux_labels = "Principal" in  9
replace aux_labels = "Santander" in  10
replace aux_labels = "Previnter" in  11
replace aux_labels = "ING/Bital" in  12
replace aux_labels = "Capitaliza" in  13
replace aux_labels = "Garante" in  14
replace aux_labels = "Inbursa" in  15
replace aux_labels = "Banamex" in  16
replace aux_labels = "Bancomer" in  17
replace aux_labels = "Correlation with observed:" in 18


* Label cols by changing var names
rename aux_ Afore
rename v1 Observed_Flow_1
rename v2 Observed_Bal_2
rename v3 Observed_Share_3
rename v4 Eq_Unif_10y_horiz_Flow_4
rename v5 Eq_Unif_10y_horiz_Bal_5
rename v6 Eq_Unif_10y_horiz_Share_6
rename v7 Eq_w_fitted_horiz_Flow_7
rename v8 Eq_w_fitted_horiz_Bal_8
rename v9 Eq_w_fitted_horiz_Share_9
rename w10 Fitted_horiz_10
rename w11 Observed_horiz_11



* Export it to csv
export delimited using "$Ready/AppendixTableIII.csv",  replace




*----------------------- END TABLES --------------------------------------------

capture erase "$Path/MatlabOutputs/StataAux"


* end do file
