%% MAIN SCRIPT FOR: 
% 'Sales Force and Competition in Financial Product Markets: 
% The Case of Mexico’s Social Security Privatization'
% by Justine Hastings, Ali Hortaçsu and Chad Syverson.
% Last revision: May, 2017

%%% SCRIPT: This main script runs the necessary scripts and functions used
%%% to generate the horizon fit and equilibrium calculations found in
%%% the paper. The output is then compiled and formatted by Stata.

% The folder should be organized as follows: Withing a Master folder, two
% subfolders: (1) MatlabInput (2) MatlabOutput
% This main code and all ancillary codes should be on (1).

% Please refer to the ReadMe for further details

clc 

clear all

%% Directory settings
% Reads current directory and sets working directories
global dirname dirname_pre dirname_output 
dirname = cd;
dirname_pre = strcat(dirname,'/Precalculations');
cd ..
masterDirectory = cd;
dirname_output = strcat(masterDirectory,'/MatlabOutputs');
cd(dirname)

%% Preliminaries
run_precalculations = 0; %1 = run precalcs for a complete run or if 
                         %    running script for first time
                         %0 = do not run, default. 

check_starting_values = 0; %1 = check convergence with different starting points
                           %0 = no check
                           %Note: this check needs a change in line 105 of
                           %calc_equil_fees.m
run_horizon_fit = 0; %1 = run horizon fit 
                     %0 = do not run; default. If it is not run, the result of
                     %    previous fit is defined into memory.

                     
                     
%% ------------- %%                     
%% SCRIPT STARTS %%                     
%% ------------- %%                   
                     


%% Consolidate data in a single filed called newdata.mat
run create_matlabfile.m

%% More global vars
global flowcap balcap gridsize ns matsize



%% Parameter values for first round of models 
flowcap=.02; % Flow Fee Cap
balcap=.0475; % Balance Fee Cap
gridsize=.0001; % Grid size increment: was gridsize=.00025;
ns= 121719; % sample size
matsize=2000; % number of individuals within a file


                    
%% Step I: Precalculations
% Set up parallel profile
parpool('torque',80)      % For this you need the profile torque and 80 cores
%parpool('local',12)      % Local profile alternative

%Check if script should run precalcs
if run_precalculations == 1
    run precalc   % You will need approx 4TB of free space
end


%% Step II: Run horizon fit and save results
% Define the horizon fit in case run_horizon_fit =0
horiz = [7
9
9
7
7
10
7
7
6
9
4
8
4
8
10
7
6]';

%Check if script should fit horizon
if run_horizon_fit == 1
    run horizonfit
end
%Create Table 10 Data: Horizon Fit:

%Display horiz
horiz

save('horizon.mat','horiz');


actual_horizon= [2.17
                4.59
                5.67
                10
                10
                10
                10
                1.25
                10
                10
                1.25
                10
                1.42
                4.59
                10
                10
                10];
            
%% Table 10            
Table10=[ horiz',  actual_horizon];

xlswrite(strcat(dirname_output,'/Table10.xls'),Table10);

%%  Step III: Create Table 9 data
% Note: Sintax for calc_equil_fees is: horizon, advertising (base vs
% neutral), sensitivity (base vs increased), govt competitor (no vs yes)

% 1. load actual fees and predicted market shares

load(fullfile(dirname_output,'base.mat'))

% 2. load calculation with 10 year horizon 

[ff_temp bb_temp]=calc_equil_fees(10*ones(17,1),1,1,1);

model0=revshare(ff_temp,bb_temp,ns,1,1);


% 3. load calculations with fitted horizon

[ff_temp bb_temp]=calc_equil_fees(horiz,1,1,1); % base adv, base sens, base govt

model1=revshare(ff_temp,bb_temp,ns,1,1);

% 4. Create data table

Base = [Base ; [99999,99999,99999]];

%% Check if starting values matter (robustness check--default = 0)
% If check==1, manually change calc_equil_fees.m line 105
if check_starting_values == 1 
    n_starting_values = 20;             % Number of different values to check
    error = zeros(n_starting_values,1);
    FF = zeros(length(ff_temp),n_starting_values);
    BB = zeros(length(bb_temp),n_starting_values);
     
   for i=1:n_starting_values
       [ff_i bb_i] = calc_equil_fees(horiz,1,1,1);
       error(i) = norm(ff_i-ff_temp)+norm(bb_i-bb_temp);
       FF(:,i) = ff_i;
       BB(:,i) = bb_i;
   end
 
   equil_shares = zeros(size(FF));
   for i=1:size(FF,2)
      equil=revshare(FF(:,i),BB(:,i),ns,1,1);
      equil_shares(:,i) = equil(1:17,3);
   end
   return % Returns and stops the script here when check = 1
end


%% Table 9
Table9 = [Base, model0(:,1:3), model1(:,1:3)];

xlswrite(strcat(dirname_output,'/Table9.xls'),Table9);


%%  Step IV: Create Table 11 data

% 1 Load model 2 data: govt player and base adv 

[ff_temp bb_temp]=calc_equil_fees(horiz,1,1,2); % base adv, base sens, govt comp

model2=revshare(ff_temp,bb_temp,ns,1,1);

% 2 Load model 3 data: govt player and neutral adv 

[ff_temp bb_temp]=calc_equil_fees(horiz,2,1,2);

model3=revshare(ff_temp,bb_temp,ns,2,1);




%% Table 11

Table11= [model1(:,1:3), model2(:,1:3), (model2(:,4)-model1(:,4))./model1(:,4),...
     model3(:,1:3), (model3(:,4)-model1(:,4))./model1(:,4)];
 
 xlswrite(strcat(dirname_output,'/Table11.xls'),Table11);
 
%% Model 7 (Table_addendum)
[ff_temp bb_temp]=calc_equil_fees(horiz,2,1,1); % Neutral adv, base sens, no govt 
model7 = revshare(ff_temp,bb_temp,ns,2,1);

Table_addendum= [model1(:,1:3), model7(:,1:3), ...
    (model7(:,4)-model1(:,4))./model1(:,4)];

xlswrite(strcat(dirname_output,'/Table_addendum.xls'),Table_addendum);

%%  Step V: Create Table 12 data

% 1 Load model 4 data: elastic investor and base adv

[ff_temp bb_temp]=calc_equil_fees(horiz,1,2,1);

model4=revshare(ff_temp,bb_temp,ns,1,2);

% 2 Load model 5 data: elastic and neutral adv 

[ff_temp bb_temp]=calc_equil_fees(horiz,2,2,1);

model5=revshare(ff_temp,bb_temp,ns,2,2);

%% Table 12

Table12= [model1(:,1:3), model4(:,1:3), (model4(:,4)-model1(:,4))./model1(:,4),...
     model5(:,1:3), (model5(:,4)-model1(:,4))./model1(:,4)];
 
xlswrite(strcat(dirname_output,'/Table12.xls'),Table12);
 

%%  Step VI: Create Table 13 data

% 1 Load model 6 data: elastic investor and NEUTRAL adv + govt  

[ff_temp bb_temp]=calc_equil_fees(horiz,2,2,2);

model6=revshare(ff_temp,bb_temp,ns,2,2);

%% Table 13

Table13= [model1(:,1:3), model6(:,1:3), ...
    (model6(:,4)-model1(:,4))./model1(:,4)];

xlswrite(strcat(dirname_output,'/Table13.xls'),Table13);

% 3 Load model extra_1213 data: elastic + govt player + BASE adv


[ff_temp bb_temp]=calc_equil_fees(horiz,1,2,2);

model_extra_1213=revshare(ff_temp,bb_temp,ns,1,2);


%% Table extra_1213
Table_extra_1213= [model1(:,1:3), model_extra_1213(:,1:3), ...
    (model_extra_1213(:,4)-model1(:,4))./model1(:,4)];


xlswrite(strcat(dirname_output,'/Table_extra_1213.xls'),Table_extra_1213);


%% Part II: calculate using higher caps

%% Part II.A: calculations for game with high cap I

%% Step 0 Run precaculations:


global dirname dirname_pre dirname_output flowcap balcap gridsize ns matsize

flowcap=.032; % Flow Fee Cap
balcap=.05; % Balance Fee Cap
gridsize=.0005; % Grid size increment
ns= 121719; % sample size
matsize=2000; % number of individuals within a file

precalc_higher(horiz);

%% Step 1: Create Data for Models 8 and 11: Govt  with cap .032 (flow) and
% .05 (balance)

[ff_temp bb_temp]=calc_equil_fees_higher_cap(horiz,1,1,2);

model8=revshare(ff_temp,bb_temp,ns,1,1);

[ff_temp bb_temp]=calc_equil_fees_higher_cap(horiz,2,1,2);

model11=revshare(ff_temp,bb_temp,ns,2,1);


%% Increase balance fee:

global dirname dirname_pre dirname_output flowcap balcap gridsize ns matsize

flowcap=.032; % Flow Fee Cap
balcap=.1; % Balance Fee Cap
gridsize=.0005; % Grid size increment
ns= 121719; % sample size
matsize=2000; % number of individuals within a file

%% Part II.B: calculations for game with high cap II

% Step 0 Run precaculations:

precalc_higher(horiz);

%% Step 1: Create Data for Models 9 and 12: Govt  with cap .032 (flow) and .1 (balance)

[ff_temp bb_temp]=calc_equil_fees_higher_cap(horiz,1,1,2);

model9=revshare(ff_temp,bb_temp,ns,1,1);

[ff_temp bb_temp]=calc_equil_fees_higher_cap(horiz,2,1,2);

model12=revshare(ff_temp,bb_temp,ns,2,1);


%% Table 14 <- Model1 and 2 = low caps; Model8 = Caps(3.2,5); Model9 = Caps(3.2,10)
Table14=[model1(:,1:3), model2(:,1:3), (model2(:,4)-model1(:,4))./model1(:,4),...
     model8(:,1:3), (model8(:,4)-model1(:,4))./model1(:,4),...
     model9(:,1:3), (model9(:,4)-model1(:,4))./model1(:,4)];
 
 xlswrite(strcat(dirname_output,'/Table14.xls'),Table14);
 
%% Table 15 <- Model1 and 2 = low caps; Model11 = Caps(3.2,5); Model12 = Caps(3.2,10)
 Table15=[model1(:,1:3), model2(:,1:3), (model2(:,4)-model1(:,4))./model1(:,4),...
     model11(:,1:3), (model11(:,4)-model1(:,4))./model1(:,4),...
     model12(:,1:3), (model12(:,4)-model1(:,4))./model1(:,4)];
 
 xlswrite(strcat(dirname_output,'/Table15.xls'),Table15);
 


%% Cost breakdown by demographics

% Uses 'incumbents_demogs_20170206.txt'
run costbydemo1213v2.m

%% Counterfactual of (2%,2%) with govt competitor (requested by reviewer)

% Uses 'incumbents_demogs_20170206.txt'
run counterfactualOfTable8.m

%% Create TABLE VIII (Table 8): Summary of simulation results with 
% discontinuous responses to government competitor

% ----------------- BOTTOM PART --------------------
% The costs breakdown in Table 8 columns are composed by 
% Base Model = model1
% (1) cont2d in costbydemotable1_app.csv
% (2) cont3d in costbydemotable1_app.csv
% (3) cont2d in costbydemotable2_app.csv
% (4) cont3d in costbydemotable1_app.csv

dataForTable8   = importdata(strcat(dirname_output,'/costbydemotable1_app.csv'));
dataForTable8_N = importdata(strcat(dirname_output,'/costbydemotable2_app.csv'));
dataForTable8 = dataForTable8.data;
dataForTable8_N = dataForTable8_N.data;

% cont2d and cont3d are columns 6 and 8 in these dataForTable8* vars

% The order we want is Low, High, Male, Female, Young, Old 
% but it's not in order. 



Table8 = [...                     % Here go columns Base Model, (1) and (2)
       NaN(2,1) dataForTable8(1:2,6) dataForTable8(1:2,8);...      %Lo,Hi
       NaN      dataForTable8(4,6)   dataForTable8(4,8);...        %Male
       NaN      dataForTable8(3,6)   dataForTable8(3,8);...        %Female
       NaN(2,1) dataForTable8(5:6,6) dataForTable8(5:6,8)];        %Yo,Old
       
Table8 = [Table8 [...             % Here go columns (3) and (4)
                dataForTable8_N(1:2,6) dataForTable8_N(1:2,8);...  %Lo,Hi
                dataForTable8_N(4,6)   dataForTable8_N(4,8);...    %Male
                dataForTable8_N(3,6)   dataForTable8_N(3,8);...    %Female
                dataForTable8_N(5:6,6) dataForTable8_N(5:6,8)]];   %Yo,Old
            
% The All costs go in the upper part.
                    


% ----------------- UPPER PART --------------------

% The top part of Table8 can be constructed from:
% baseModel = model1     <--- Already in memory
% (1) = model8
% (2) = model9
% (3) = model11
% (4) = model12

% Use calculateAtCap.m to obtain a col vector with Mkt Shares of afores at
% cap and Percent of afores pricing at cap.

% Go by columns:
baseModelCol = [baseModel(4,1:3)'; NaN(3,1)];
col1 = [model8(4,1:3)';  calculateAtCap(model8); ...
       (model8(18,4)  - model1(18,4)) / model1(18,4)];                        
col2 = [model9(4,1:3)';  calculateAtCap(model9); ...
       (model9(18,4)  - model1(18,4)) / model1(18,4)];
col3 = [model11(4,1:3)'; calculateAtCap(model11); ...
       (model11(18,4) - model1(18,4)) / model1(18,4)];
col4 = [model12(4,1:3)'; calculateAtCap(model12); ...
       (model12(18,4) - model1(18,4)) / model1(18,4)];

% Paste together the columns:
Table8 = [baseModelCol col1 col2 col3 col4;... % Upper  part
            Table8/100];                       % Bottom part
                    
xlswrite(strcat(dirname_output,'/Table8.xls'),Table8);   


%% Create Table IX: Summary of outcomes for demand and supply-side policies

% The top part of the columns are:
% (1) = model4
% (2) = model_extra_1213
% (3) = model6
% The bottom part (costs) of the columns are:
% (1) = cont3d in costbydemotable2_updated.csv
% (2) = cont7d ''   ''
% (3) = cont5d ''   ''
% We want All, Low, High, Young, Old, Male, Female
% But we have Low, High, Female, Male, Young, Old
dataForTable9 = importdata(strcat(dirname_output,'/costbydemotable2_updated.csv'));
dataForTable9 = dataForTable9.data/100;     % /100 to get percentages
% In terms of dataForTable9, we need cols 4, 12 and 8 for (1), (2) and (3)

% Go by columns:
col1 = [calculateAtCapSpecific(model4,.02,.0475);...         % At cap
        (model4(18,4) - model1(18,4)) / model1(18,4);...     % All 
        dataForTable9(1:2,4);...                             % Lo and Hi
        dataForTable9(5:6,4);...                             % Yo and Old
        dataForTable9(4,4);...                               % Male
        dataForTable9(3,4)];                                 % Female
col2 = [calculateAtCapSpecific(model_extra_1213,.02,.0475);... % At cap
        (model_extra_1213(18,4) - model1(18,4)) / model1(18,4);...% All 
        dataForTable9(1:2,12);...                             % Lo and Hi
        dataForTable9(5:6,12);...                             % Yo and Old
        dataForTable9(4,12);...                               % Male
        dataForTable9(3,12)];                                 % Female
col3 = [calculateAtCapSpecific(model6,.02,.0475);...         % At cap
        (model6(18,4) - model1(18,4)) / model1(18,4);...     % All 
        dataForTable9(1:2,8);...                             % Lo and Hi
        dataForTable9(5:6,8);...                             % Yo and Old
        dataForTable9(4,8);...                               % Male
        dataForTable9(3,8)];                                 % Female


% Paste together the columns:
TableIX = [ col1 col2 col3 ];           % The name Table9 is already taken
                   
xlswrite(strcat(dirname_output,'/TableIX.xls'),TableIX); 


%% Create both graphs
run graph_XXIprofit.m            % With baseline demand 
run graph_XXIprofit_neutral.m    % With neutral demand 


%% Close parallel pool
delete(gcp('nocreate'))




